# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NgwArgs', 'Ngw']

@pulumi.input_type
class NgwArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[builtins.str],
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
                 spec: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]] = None):
        """
        The set of arguments for constructing a Ngw resource.
        :param pulumi.Input[builtins.str] vpc_id: NAT网关所在私有网络的ID。
        :param pulumi.Input[builtins.int] billing_type: NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        :param pulumi.Input[builtins.str] description: NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        :param pulumi.Input[builtins.str] nat_gateway_name: NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        :param pulumi.Input[builtins.str] network_type: NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        :param pulumi.Input[builtins.int] period: 购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        :param pulumi.Input[builtins.str] period_unit: 购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        :param pulumi.Input[builtins.str] project_name: NAT网关所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.bool] smart_schedule_enabled: 是否开启智能调度。
        :param pulumi.Input[builtins.str] smart_schedule_rule: 智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        :param pulumi.Input[builtins.str] spec: NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        :param pulumi.Input[builtins.str] subnet_id: NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if nat_gateway_name is not None:
            pulumi.set(__self__, "nat_gateway_name", nat_gateway_name)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if smart_schedule_enabled is not None:
            pulumi.set(__self__, "smart_schedule_enabled", smart_schedule_enabled)
        if smart_schedule_rule is not None:
            pulumi.set(__self__, "smart_schedule_rule", smart_schedule_rule)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        NAT网关所在私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="natGatewayName")
    def nat_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        """
        return pulumi.get(self, "nat_gateway_name")

    @nat_gateway_name.setter
    def nat_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_name", value)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="smartScheduleEnabled")
    def smart_schedule_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启智能调度。
        """
        return pulumi.get(self, "smart_schedule_enabled")

    @smart_schedule_enabled.setter
    def smart_schedule_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "smart_schedule_enabled", value)

    @property
    @pulumi.getter(name="smartScheduleRule")
    def smart_schedule_rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        """
        return pulumi.get(self, "smart_schedule_rule")

    @smart_schedule_rule.setter
    def smart_schedule_rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "smart_schedule_rule", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _NgwState:
    def __init__(__self__, *,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 direct_mode: Optional[pulumi.Input[builtins.bool]] = None,
                 dnat_entry_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 eip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input['NgwEipAddressArgs']]]] = None,
                 expired_time: Optional[pulumi.Input[builtins.str]] = None,
                 lock_reason: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input['NgwNatIpAddressArgs']]]] = None,
                 network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
                 snat_entry_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 spec: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Ngw resources.
        :param pulumi.Input[builtins.int] billing_type: NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        :param pulumi.Input[builtins.str] business_status: NAT网关是否被锁定。空值：正常未被锁定。Normal：正常未被锁定。FinancialLocked：因欠费被锁定。
        :param pulumi.Input[builtins.str] created_time: 创建时间
        :param pulumi.Input[builtins.str] deleted_time: 删除时间
        :param pulumi.Input[builtins.str] description: NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        :param pulumi.Input[builtins.bool] direct_mode: 标识该nat是直通还是非直通。   - true（默认）：EIP直通nat网关。   - false：非EIP直通nat网关。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dnat_entry_ids: DNAT规则ID列表。
        :param pulumi.Input[builtins.str] expired_time: 包年包月NAT网关到期时间。仅包年包月计费类型的NAT网关会返回此参数。
        :param pulumi.Input[builtins.str] lock_reason: NAT被锁定的原因。financial：因欠费被锁定。security：因安全原因被锁定。
        :param pulumi.Input[builtins.str] nat_gateway_id: NAT网关ID。
        :param pulumi.Input[builtins.str] nat_gateway_name: NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        :param pulumi.Input[builtins.str] network_interface_id: NAT网关占用的网卡ID。
        :param pulumi.Input[builtins.str] network_type: NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        :param pulumi.Input[builtins.str] overdue_time: 资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值。
        :param pulumi.Input[builtins.int] period: 购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        :param pulumi.Input[builtins.str] period_unit: 购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        :param pulumi.Input[builtins.str] project_name: NAT网关所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.bool] smart_schedule_enabled: 是否开启智能调度。
        :param pulumi.Input[builtins.str] smart_schedule_rule: 智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] snat_entry_ids: SNAT规则ID列表。
        :param pulumi.Input[builtins.str] spec: NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        :param pulumi.Input[builtins.str] status: NAT网关的状态。Available：可用。Creating：创建中。Pending：操作中。Deleting：删除中。
        :param pulumi.Input[builtins.str] subnet_id: NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        :param pulumi.Input[builtins.str] updated_time: NAT网关的最后操作时间。
        :param pulumi.Input[builtins.str] vpc_id: NAT网关所在私有网络的ID。
        :param pulumi.Input[builtins.str] zone_id: NAT网关所属主可用区的ID。
        """
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if direct_mode is not None:
            pulumi.set(__self__, "direct_mode", direct_mode)
        if dnat_entry_ids is not None:
            pulumi.set(__self__, "dnat_entry_ids", dnat_entry_ids)
        if eip_addresses is not None:
            pulumi.set(__self__, "eip_addresses", eip_addresses)
        if expired_time is not None:
            pulumi.set(__self__, "expired_time", expired_time)
        if lock_reason is not None:
            pulumi.set(__self__, "lock_reason", lock_reason)
        if nat_gateway_id is not None:
            pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_gateway_name is not None:
            pulumi.set(__self__, "nat_gateway_name", nat_gateway_name)
        if nat_ip_addresses is not None:
            pulumi.set(__self__, "nat_ip_addresses", nat_ip_addresses)
        if network_interface_id is not None:
            pulumi.set(__self__, "network_interface_id", network_interface_id)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if smart_schedule_enabled is not None:
            pulumi.set(__self__, "smart_schedule_enabled", smart_schedule_enabled)
        if smart_schedule_rule is not None:
            pulumi.set(__self__, "smart_schedule_rule", smart_schedule_rule)
        if snat_entry_ids is not None:
            pulumi.set(__self__, "snat_entry_ids", snat_entry_ids)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关是否被锁定。空值：正常未被锁定。Normal：正常未被锁定。FinancialLocked：因欠费被锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除时间
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="directMode")
    def direct_mode(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        标识该nat是直通还是非直通。   - true（默认）：EIP直通nat网关。   - false：非EIP直通nat网关。
        """
        return pulumi.get(self, "direct_mode")

    @direct_mode.setter
    def direct_mode(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "direct_mode", value)

    @property
    @pulumi.getter(name="dnatEntryIds")
    def dnat_entry_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        DNAT规则ID列表。
        """
        return pulumi.get(self, "dnat_entry_ids")

    @dnat_entry_ids.setter
    def dnat_entry_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "dnat_entry_ids", value)

    @property
    @pulumi.getter(name="eipAddresses")
    def eip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NgwEipAddressArgs']]]]:
        return pulumi.get(self, "eip_addresses")

    @eip_addresses.setter
    def eip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NgwEipAddressArgs']]]]):
        pulumi.set(self, "eip_addresses", value)

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        包年包月NAT网关到期时间。仅包年包月计费类型的NAT网关会返回此参数。
        """
        return pulumi.get(self, "expired_time")

    @expired_time.setter
    def expired_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expired_time", value)

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT被锁定的原因。financial：因欠费被锁定。security：因安全原因被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @lock_reason.setter
    def lock_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_reason", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natGatewayName")
    def nat_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        """
        return pulumi.get(self, "nat_gateway_name")

    @nat_gateway_name.setter
    def nat_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_name", value)

    @property
    @pulumi.getter(name="natIpAddresses")
    def nat_ip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NgwNatIpAddressArgs']]]]:
        return pulumi.get(self, "nat_ip_addresses")

    @nat_ip_addresses.setter
    def nat_ip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NgwNatIpAddressArgs']]]]):
        pulumi.set(self, "nat_ip_addresses", value)

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关占用的网卡ID。
        """
        return pulumi.get(self, "network_interface_id")

    @network_interface_id.setter
    def network_interface_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_interface_id", value)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        """
        return pulumi.get(self, "network_type")

    @network_type.setter
    def network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_type", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="smartScheduleEnabled")
    def smart_schedule_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启智能调度。
        """
        return pulumi.get(self, "smart_schedule_enabled")

    @smart_schedule_enabled.setter
    def smart_schedule_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "smart_schedule_enabled", value)

    @property
    @pulumi.getter(name="smartScheduleRule")
    def smart_schedule_rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        """
        return pulumi.get(self, "smart_schedule_rule")

    @smart_schedule_rule.setter
    def smart_schedule_rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "smart_schedule_rule", value)

    @property
    @pulumi.getter(name="snatEntryIds")
    def snat_entry_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        SNAT规则ID列表。
        """
        return pulumi.get(self, "snat_entry_ids")

    @snat_entry_ids.setter
    def snat_entry_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "snat_entry_ids", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的状态。Available：可用。Creating：创建中。Pending：操作中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NgwTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关的最后操作时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所在私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关所属主可用区的ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:natgateway/ngw:Ngw")
class Ngw(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
                 spec: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwTagArgs', 'NgwTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        NAT网关为私有网络内的云服务器提供网络地址转换服务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_ngw_demo = bytepluscc.natgateway.Ngw("NatGatewayNGWDemo",
            spec="Small",
            vpc_id="vpc-2f8kicbjkot8g4f4pzyyxxxxx",
            subnet_id="subnet-3hicda1321wqo3nkipk4xxxxx",
            nat_gateway_name="NatGatewayNGWDemo",
            billing_type=2,
            project_name="default",
            network_type="internet",
            description="NatGatewayNGWDemo",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/ngw:Ngw example "nat_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] billing_type: NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        :param pulumi.Input[builtins.str] description: NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        :param pulumi.Input[builtins.str] nat_gateway_name: NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        :param pulumi.Input[builtins.str] network_type: NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        :param pulumi.Input[builtins.int] period: 购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        :param pulumi.Input[builtins.str] period_unit: 购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        :param pulumi.Input[builtins.str] project_name: NAT网关所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.bool] smart_schedule_enabled: 是否开启智能调度。
        :param pulumi.Input[builtins.str] smart_schedule_rule: 智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        :param pulumi.Input[builtins.str] spec: NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        :param pulumi.Input[builtins.str] subnet_id: NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        :param pulumi.Input[builtins.str] vpc_id: NAT网关所在私有网络的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NgwArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        NAT网关为私有网络内的云服务器提供网络地址转换服务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_ngw_demo = bytepluscc.natgateway.Ngw("NatGatewayNGWDemo",
            spec="Small",
            vpc_id="vpc-2f8kicbjkot8g4f4pzyyxxxxx",
            subnet_id="subnet-3hicda1321wqo3nkipk4xxxxx",
            nat_gateway_name="NatGatewayNGWDemo",
            billing_type=2,
            project_name="default",
            network_type="internet",
            description="NatGatewayNGWDemo",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/ngw:Ngw example "nat_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param NgwArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NgwArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 network_type: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
                 spec: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwTagArgs', 'NgwTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NgwArgs.__new__(NgwArgs)

            __props__.__dict__["billing_type"] = billing_type
            __props__.__dict__["description"] = description
            __props__.__dict__["nat_gateway_name"] = nat_gateway_name
            __props__.__dict__["network_type"] = network_type
            __props__.__dict__["period"] = period
            __props__.__dict__["period_unit"] = period_unit
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["smart_schedule_enabled"] = smart_schedule_enabled
            __props__.__dict__["smart_schedule_rule"] = smart_schedule_rule
            __props__.__dict__["spec"] = spec
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["business_status"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["deleted_time"] = None
            __props__.__dict__["direct_mode"] = None
            __props__.__dict__["dnat_entry_ids"] = None
            __props__.__dict__["eip_addresses"] = None
            __props__.__dict__["expired_time"] = None
            __props__.__dict__["lock_reason"] = None
            __props__.__dict__["nat_gateway_id"] = None
            __props__.__dict__["nat_ip_addresses"] = None
            __props__.__dict__["network_interface_id"] = None
            __props__.__dict__["overdue_time"] = None
            __props__.__dict__["snat_entry_ids"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["zone_id"] = None
        super(Ngw, __self__).__init__(
            'bytepluscc:natgateway/ngw:Ngw',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            billing_type: Optional[pulumi.Input[builtins.int]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            deleted_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            direct_mode: Optional[pulumi.Input[builtins.bool]] = None,
            dnat_entry_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            eip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwEipAddressArgs', 'NgwEipAddressArgsDict']]]]] = None,
            expired_time: Optional[pulumi.Input[builtins.str]] = None,
            lock_reason: Optional[pulumi.Input[builtins.str]] = None,
            nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            nat_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwNatIpAddressArgs', 'NgwNatIpAddressArgsDict']]]]] = None,
            network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
            network_type: Optional[pulumi.Input[builtins.str]] = None,
            overdue_time: Optional[pulumi.Input[builtins.str]] = None,
            period: Optional[pulumi.Input[builtins.int]] = None,
            period_unit: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            smart_schedule_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            smart_schedule_rule: Optional[pulumi.Input[builtins.str]] = None,
            snat_entry_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            spec: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NgwTagArgs', 'NgwTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Ngw':
        """
        Get an existing Ngw resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] billing_type: NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        :param pulumi.Input[builtins.str] business_status: NAT网关是否被锁定。空值：正常未被锁定。Normal：正常未被锁定。FinancialLocked：因欠费被锁定。
        :param pulumi.Input[builtins.str] created_time: 创建时间
        :param pulumi.Input[builtins.str] deleted_time: 删除时间
        :param pulumi.Input[builtins.str] description: NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        :param pulumi.Input[builtins.bool] direct_mode: 标识该nat是直通还是非直通。   - true（默认）：EIP直通nat网关。   - false：非EIP直通nat网关。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dnat_entry_ids: DNAT规则ID列表。
        :param pulumi.Input[builtins.str] expired_time: 包年包月NAT网关到期时间。仅包年包月计费类型的NAT网关会返回此参数。
        :param pulumi.Input[builtins.str] lock_reason: NAT被锁定的原因。financial：因欠费被锁定。security：因安全原因被锁定。
        :param pulumi.Input[builtins.str] nat_gateway_id: NAT网关ID。
        :param pulumi.Input[builtins.str] nat_gateway_name: NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        :param pulumi.Input[builtins.str] network_interface_id: NAT网关占用的网卡ID。
        :param pulumi.Input[builtins.str] network_type: NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        :param pulumi.Input[builtins.str] overdue_time: 资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值。
        :param pulumi.Input[builtins.int] period: 购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        :param pulumi.Input[builtins.str] period_unit: 购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        :param pulumi.Input[builtins.str] project_name: NAT网关所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.bool] smart_schedule_enabled: 是否开启智能调度。
        :param pulumi.Input[builtins.str] smart_schedule_rule: 智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] snat_entry_ids: SNAT规则ID列表。
        :param pulumi.Input[builtins.str] spec: NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        :param pulumi.Input[builtins.str] status: NAT网关的状态。Available：可用。Creating：创建中。Pending：操作中。Deleting：删除中。
        :param pulumi.Input[builtins.str] subnet_id: NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        :param pulumi.Input[builtins.str] updated_time: NAT网关的最后操作时间。
        :param pulumi.Input[builtins.str] vpc_id: NAT网关所在私有网络的ID。
        :param pulumi.Input[builtins.str] zone_id: NAT网关所属主可用区的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NgwState.__new__(_NgwState)

        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["deleted_time"] = deleted_time
        __props__.__dict__["description"] = description
        __props__.__dict__["direct_mode"] = direct_mode
        __props__.__dict__["dnat_entry_ids"] = dnat_entry_ids
        __props__.__dict__["eip_addresses"] = eip_addresses
        __props__.__dict__["expired_time"] = expired_time
        __props__.__dict__["lock_reason"] = lock_reason
        __props__.__dict__["nat_gateway_id"] = nat_gateway_id
        __props__.__dict__["nat_gateway_name"] = nat_gateway_name
        __props__.__dict__["nat_ip_addresses"] = nat_ip_addresses
        __props__.__dict__["network_interface_id"] = network_interface_id
        __props__.__dict__["network_type"] = network_type
        __props__.__dict__["overdue_time"] = overdue_time
        __props__.__dict__["period"] = period
        __props__.__dict__["period_unit"] = period_unit
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["smart_schedule_enabled"] = smart_schedule_enabled
        __props__.__dict__["smart_schedule_rule"] = smart_schedule_rule
        __props__.__dict__["snat_entry_ids"] = snat_entry_ids
        __props__.__dict__["spec"] = spec
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_id"] = zone_id
        return Ngw(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.int]:
        """
        NAT网关的计费方式。取值如下：1 ：包年包月。2（默认值）：按量计费-按规格计费。3：按量计费-按使用量计费。当NetworkType传入intranet时，本参数仅支持且必须传入3。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关是否被锁定。空值：正常未被锁定。Normal：正常未被锁定。FinancialLocked：因欠费被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> pulumi.Output[builtins.str]:
        """
        删除时间
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的描述。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1 ～ 255个字符。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="directMode")
    def direct_mode(self) -> pulumi.Output[builtins.bool]:
        """
        标识该nat是直通还是非直通。   - true（默认）：EIP直通nat网关。   - false：非EIP直通nat网关。
        """
        return pulumi.get(self, "direct_mode")

    @property
    @pulumi.getter(name="dnatEntryIds")
    def dnat_entry_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        DNAT规则ID列表。
        """
        return pulumi.get(self, "dnat_entry_ids")

    @property
    @pulumi.getter(name="eipAddresses")
    def eip_addresses(self) -> pulumi.Output[Sequence['outputs.NgwEipAddress']]:
        return pulumi.get(self, "eip_addresses")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> pulumi.Output[builtins.str]:
        """
        包年包月NAT网关到期时间。仅包年包月计费类型的NAT网关会返回此参数。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> pulumi.Output[builtins.str]:
        """
        NAT被锁定的原因。financial：因欠费被锁定。security：因安全原因被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natGatewayName")
    def nat_gateway_name(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的名称。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认是NAT网关实例的ID。
        """
        return pulumi.get(self, "nat_gateway_name")

    @property
    @pulumi.getter(name="natIpAddresses")
    def nat_ip_addresses(self) -> pulumi.Output[Sequence['outputs.NgwNatIpAddress']]:
        return pulumi.get(self, "nat_ip_addresses")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关占用的网卡ID。
        """
        return pulumi.get(self, "network_interface_id")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关类型。internet：公网NAT网关。intranet：私网NAT网关。
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> pulumi.Output[builtins.str]:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[builtins.int]:
        """
        购买包年包月NAT网关的时长，默认1。当PeriodUnit传入Month，Period取值范围：1 ~ 9、12、24、36。当PeriodUnit传入Year，Period取值范围：1 ~ 3。
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> pulumi.Output[builtins.str]:
        """
        购买包年包月NAT网关时长的单位，默认Month。Month ：月。Year ：年。
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="smartScheduleEnabled")
    def smart_schedule_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启智能调度。
        """
        return pulumi.get(self, "smart_schedule_enabled")

    @property
    @pulumi.getter(name="smartScheduleRule")
    def smart_schedule_rule(self) -> pulumi.Output[builtins.str]:
        """
        智能调度策略规则。ChinaMobile：中国移动。ChinaUnicom：中国联通。ChinaTelecom：中国电信。BGP：BGP多线。
        """
        return pulumi.get(self, "smart_schedule_rule")

    @property
    @pulumi.getter(name="snatEntryIds")
    def snat_entry_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        SNAT规则ID列表。
        """
        return pulumi.get(self, "snat_entry_ids")

    @property
    @pulumi.getter
    def spec(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的规格。Small（默认）：小型。Medium：中型。Large：大型。Extra*Large*1：超大型-1。Extra*Large*2：超大型-2。
        """
        return pulumi.get(self, "spec")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的状态。Available：可用。Creating：创建中。Pending：操作中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关所在子网的ID。传入的子网，必须是VpcId传入的私有网络的子网。子网内至少有一个可用的私网IP。系统自动生成的NAT网关网卡将占用该子网一个私网IP。子网所在的可用区需要已部署NAT网关资源。子网所在可用区将作为NAT网关的主可用区，并自动关联备可用区。当主可用区发生故障时，NAT网关自动切换到备可用区。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NgwTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关的最后操作时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关所在私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关所属主可用区的ID。
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDbAccountResult',
    'AwaitableGetDbAccountResult',
    'get_db_account',
    'get_db_account_output',
]

@pulumi.output_type
class GetDbAccountResult:
    """
    A collection of values returned by getDbAccount.
    """
    def __init__(__self__, account_desc=None, account_name=None, account_password=None, account_privileges=None, account_privileges_sqls=None, account_status=None, account_type=None, has_table_column_privilege_db_names=None, host=None, id=None, instance_id=None, table_column_privileges=None):
        if account_desc and not isinstance(account_desc, str):
            raise TypeError("Expected argument 'account_desc' to be a str")
        pulumi.set(__self__, "account_desc", account_desc)
        if account_name and not isinstance(account_name, str):
            raise TypeError("Expected argument 'account_name' to be a str")
        pulumi.set(__self__, "account_name", account_name)
        if account_password and not isinstance(account_password, str):
            raise TypeError("Expected argument 'account_password' to be a str")
        pulumi.set(__self__, "account_password", account_password)
        if account_privileges and not isinstance(account_privileges, list):
            raise TypeError("Expected argument 'account_privileges' to be a list")
        pulumi.set(__self__, "account_privileges", account_privileges)
        if account_privileges_sqls and not isinstance(account_privileges_sqls, list):
            raise TypeError("Expected argument 'account_privileges_sqls' to be a list")
        pulumi.set(__self__, "account_privileges_sqls", account_privileges_sqls)
        if account_status and not isinstance(account_status, str):
            raise TypeError("Expected argument 'account_status' to be a str")
        pulumi.set(__self__, "account_status", account_status)
        if account_type and not isinstance(account_type, str):
            raise TypeError("Expected argument 'account_type' to be a str")
        pulumi.set(__self__, "account_type", account_type)
        if has_table_column_privilege_db_names and not isinstance(has_table_column_privilege_db_names, list):
            raise TypeError("Expected argument 'has_table_column_privilege_db_names' to be a list")
        pulumi.set(__self__, "has_table_column_privilege_db_names", has_table_column_privilege_db_names)
        if host and not isinstance(host, str):
            raise TypeError("Expected argument 'host' to be a str")
        pulumi.set(__self__, "host", host)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if table_column_privileges and not isinstance(table_column_privileges, list):
            raise TypeError("Expected argument 'table_column_privileges' to be a list")
        pulumi.set(__self__, "table_column_privileges", table_column_privileges)

    @property
    @pulumi.getter(name="accountDesc")
    def account_desc(self) -> builtins.str:
        """
        账号信息描述信息，长度不超过 256 个字符。
        """
        return pulumi.get(self, "account_desc")

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> builtins.str:
        """
        数据库账号名称。命名规则如下：长度为 2~32 个字符。以字母开头，以字母或数字结尾。由字母、数字、下划线（_）和中划线（-）组成。账号名称在实例内必须是唯一的。不能使用某些预留字，被禁用的预留字请参见禁用词列表。说明在高权限账号名称中可使用关键字 root 和 admin。
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> builtins.str:
        """
        数据库账号的密码。规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的至少三种组成。特殊字符为 !@#$%^&*()_+-=,.&?|/。
        """
        return pulumi.get(self, "account_password")

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> Sequence['outputs.GetDbAccountAccountPrivilegeResult']:
        """
        账号的指定数据库权限信息。说明当 AccountType 取值为 Super 时，无需为 AccountPrivileges 传值
        """
        return pulumi.get(self, "account_privileges")

    @property
    @pulumi.getter(name="accountPrivilegesSqls")
    def account_privileges_sqls(self) -> Sequence[builtins.str]:
        """
        账号的指定数据库权限信息的 SQL 语句。
        """
        return pulumi.get(self, "account_privileges_sqls")

    @property
    @pulumi.getter(name="accountStatus")
    def account_status(self) -> builtins.str:
        """
        账号状态，取值为：Unavailable：不可用。Available：可用。
        """
        return pulumi.get(self, "account_status")

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> builtins.str:
        """
        账号类型，取值范围：Super：高权限账号。Normal：普通账号。
        """
        return pulumi.get(self, "account_type")

    @property
    @pulumi.getter(name="hasTableColumnPrivilegeDbNames")
    def has_table_column_privilege_db_names(self) -> Sequence[builtins.str]:
        """
        账号拥有的表列权限所属的数据库。说明如果账号没有表列权限，则不返回该字段。
        """
        return pulumi.get(self, "has_table_column_privilege_db_names")

    @property
    @pulumi.getter
    def host(self) -> builtins.str:
        """
        指定的数据库账号可以访问数据库的 IP 地址。
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="tableColumnPrivileges")
    def table_column_privileges(self) -> Sequence['outputs.GetDbAccountTableColumnPrivilegeResult']:
        """
        账号的表列权限设置。
        """
        return pulumi.get(self, "table_column_privileges")


class AwaitableGetDbAccountResult(GetDbAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDbAccountResult(
            account_desc=self.account_desc,
            account_name=self.account_name,
            account_password=self.account_password,
            account_privileges=self.account_privileges,
            account_privileges_sqls=self.account_privileges_sqls,
            account_status=self.account_status,
            account_type=self.account_type,
            has_table_column_privilege_db_names=self.has_table_column_privilege_db_names,
            host=self.host,
            id=self.id,
            instance_id=self.instance_id,
            table_column_privileges=self.table_column_privileges)


def get_db_account(id: Optional[builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDbAccountResult:
    """
    Data Source schema for Byteplus::RDSMySQL::DBAccount


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:rdsmysql/getDbAccount:getDbAccount', __args__, opts=opts, typ=GetDbAccountResult).value

    return AwaitableGetDbAccountResult(
        account_desc=pulumi.get(__ret__, 'account_desc'),
        account_name=pulumi.get(__ret__, 'account_name'),
        account_password=pulumi.get(__ret__, 'account_password'),
        account_privileges=pulumi.get(__ret__, 'account_privileges'),
        account_privileges_sqls=pulumi.get(__ret__, 'account_privileges_sqls'),
        account_status=pulumi.get(__ret__, 'account_status'),
        account_type=pulumi.get(__ret__, 'account_type'),
        has_table_column_privilege_db_names=pulumi.get(__ret__, 'has_table_column_privilege_db_names'),
        host=pulumi.get(__ret__, 'host'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        table_column_privileges=pulumi.get(__ret__, 'table_column_privileges'))
def get_db_account_output(id: Optional[pulumi.Input[builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDbAccountResult]:
    """
    Data Source schema for Byteplus::RDSMySQL::DBAccount


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:rdsmysql/getDbAccount:getDbAccount', __args__, opts=opts, typ=GetDbAccountResult)
    return __ret__.apply(lambda __response__: GetDbAccountResult(
        account_desc=pulumi.get(__response__, 'account_desc'),
        account_name=pulumi.get(__response__, 'account_name'),
        account_password=pulumi.get(__response__, 'account_password'),
        account_privileges=pulumi.get(__response__, 'account_privileges'),
        account_privileges_sqls=pulumi.get(__response__, 'account_privileges_sqls'),
        account_status=pulumi.get(__response__, 'account_status'),
        account_type=pulumi.get(__response__, 'account_type'),
        has_table_column_privilege_db_names=pulumi.get(__response__, 'has_table_column_privilege_db_names'),
        host=pulumi.get(__response__, 'host'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        table_column_privileges=pulumi.get(__response__, 'table_column_privileges')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEnisResult',
    'AwaitableGetEnisResult',
    'get_enis',
    'get_enis_output',
]

@pulumi.output_type
class GetEnisResult:
    """
    A collection of values returned by getEnis.
    """
    def __init__(__self__, id=None, ids=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the data source.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        Set of Resource Identifiers.
        """
        return pulumi.get(self, "ids")


class AwaitableGetEnisResult(GetEnisResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnisResult(
            id=self.id,
            ids=self.ids)


def get_enis(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnisResult:
    """
    Plural Data Source schema for Byteplus::VPC::ENI
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getEnis:getEnis', __args__, opts=opts, typ=GetEnisResult).value

    return AwaitableGetEnisResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'))
def get_enis_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEnisResult]:
    """
    Plural Data Source schema for Byteplus::VPC::ENI
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getEnis:getEnis', __args__, opts=opts, typ=GetEnisResult)
    return __ret__.apply(lambda __response__: GetEnisResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSecurityGroupResult',
    'AwaitableGetSecurityGroupResult',
    'get_security_group',
    'get_security_group_output',
]

@pulumi.output_type
class GetSecurityGroupResult:
    """
    A collection of values returned by getSecurityGroup.
    """
    def __init__(__self__, creation_time=None, description=None, egress_permissions=None, id=None, ingress_permissions=None, project_name=None, security_group_id=None, security_group_name=None, service_managed=None, status=None, tags=None, type=None, vpc_id=None):
        if creation_time and not isinstance(creation_time, str):
            raise TypeError("Expected argument 'creation_time' to be a str")
        pulumi.set(__self__, "creation_time", creation_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if egress_permissions and not isinstance(egress_permissions, list):
            raise TypeError("Expected argument 'egress_permissions' to be a list")
        pulumi.set(__self__, "egress_permissions", egress_permissions)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ingress_permissions and not isinstance(ingress_permissions, list):
            raise TypeError("Expected argument 'ingress_permissions' to be a list")
        pulumi.set(__self__, "ingress_permissions", ingress_permissions)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if security_group_id and not isinstance(security_group_id, str):
            raise TypeError("Expected argument 'security_group_id' to be a str")
        pulumi.set(__self__, "security_group_id", security_group_id)
        if security_group_name and not isinstance(security_group_name, str):
            raise TypeError("Expected argument 'security_group_name' to be a str")
        pulumi.set(__self__, "security_group_name", security_group_name)
        if service_managed and not isinstance(service_managed, bool):
            raise TypeError("Expected argument 'service_managed' to be a bool")
        pulumi.set(__self__, "service_managed", service_managed)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> builtins.str:
        """
        安全组创建时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        安全组的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="egressPermissions")
    def egress_permissions(self) -> Sequence['outputs.GetSecurityGroupEgressPermissionResult']:
        """
        安全组出向规则描述信息。未改动的信息按照原信息返回，未填或者变动的内容视为修改，请按需填写。
        """
        return pulumi.get(self, "egress_permissions")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ingressPermissions")
    def ingress_permissions(self) -> Sequence['outputs.GetSecurityGroupIngressPermissionResult']:
        """
        安全组入向规则描述信息。未改动的信息按照原信息返回，未填或者变动的内容视为修改，请按需填写。
        """
        return pulumi.get(self, "ingress_permissions")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        安全组所属项目名称。不填默认项目为default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        """
        安全组ID。
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> builtins.str:
        """
        安全组的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认是安全组的ID。
        """
        return pulumi.get(self, "security_group_name")

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> builtins.bool:
        """
        安全组是否为托管安全组。true为托管安全组，false为非托管安全组。
        """
        return pulumi.get(self, "service_managed")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        安全组状态。Available为可用，Creating为创建中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetSecurityGroupTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        安全组类型。1、default：默认安全组。2、normal：自定义安全组。3、VpnGW： VPN网关安全组。4、NatGW： Nat网关安全组。 5、cidr_only：CIDR-Only安全组。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        安全组所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetSecurityGroupResult(GetSecurityGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecurityGroupResult(
            creation_time=self.creation_time,
            description=self.description,
            egress_permissions=self.egress_permissions,
            id=self.id,
            ingress_permissions=self.ingress_permissions,
            project_name=self.project_name,
            security_group_id=self.security_group_id,
            security_group_name=self.security_group_name,
            service_managed=self.service_managed,
            status=self.status,
            tags=self.tags,
            type=self.type,
            vpc_id=self.vpc_id)


def get_security_group(id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecurityGroupResult:
    """
    Data Source schema for Byteplus::VPC::SecurityGroup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getSecurityGroup:getSecurityGroup', __args__, opts=opts, typ=GetSecurityGroupResult).value

    return AwaitableGetSecurityGroupResult(
        creation_time=pulumi.get(__ret__, 'creation_time'),
        description=pulumi.get(__ret__, 'description'),
        egress_permissions=pulumi.get(__ret__, 'egress_permissions'),
        id=pulumi.get(__ret__, 'id'),
        ingress_permissions=pulumi.get(__ret__, 'ingress_permissions'),
        project_name=pulumi.get(__ret__, 'project_name'),
        security_group_id=pulumi.get(__ret__, 'security_group_id'),
        security_group_name=pulumi.get(__ret__, 'security_group_name'),
        service_managed=pulumi.get(__ret__, 'service_managed'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_security_group_output(id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecurityGroupResult]:
    """
    Data Source schema for Byteplus::VPC::SecurityGroup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getSecurityGroup:getSecurityGroup', __args__, opts=opts, typ=GetSecurityGroupResult)
    return __ret__.apply(lambda __response__: GetSecurityGroupResult(
        creation_time=pulumi.get(__response__, 'creation_time'),
        description=pulumi.get(__response__, 'description'),
        egress_permissions=pulumi.get(__response__, 'egress_permissions'),
        id=pulumi.get(__response__, 'id'),
        ingress_permissions=pulumi.get(__response__, 'ingress_permissions'),
        project_name=pulumi.get(__response__, 'project_name'),
        security_group_id=pulumi.get(__response__, 'security_group_id'),
        security_group_name=pulumi.get(__response__, 'security_group_name'),
        service_managed=pulumi.get(__response__, 'service_managed'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SubnetArgs', 'Subnet']

@pulumi.input_type
class SubnetArgs:
    def __init__(__self__, *,
                 cidr_block: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 zone_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_ipv6: Optional[pulumi.Input[builtins.bool]] = None,
                 ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['SubnetTagArgs']]]] = None):
        """
        The set of arguments for constructing a Subnet resource.
        :param pulumi.Input[builtins.str] cidr_block: 子网的IPv4网段。
        :param pulumi.Input[builtins.str] vpc_id: 子网所属VPC的ID。
        :param pulumi.Input[builtins.str] zone_id: 要创建的子网所属的可用区ID，更多可用区信息请参见地域和可用区。
        :param pulumi.Input[builtins.str] description: 子网的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不能以http://或https://开头。
        :param pulumi.Input[builtins.bool] enable_ipv6: 开启/关闭IPv6功能。仅当子网所属的VPC开通IPv6功能时，可配置此参数。1、true：开启。2、false：关闭。仅当子网内没有分配IPv6地址的云资源时，可配置此取值。
        :param pulumi.Input[builtins.str] ipv6_cidr_block: 子网IPv6网段。1、创建/修改时请输入子网IPv6网段的最后8比特位（子网的掩码固定为/64）。2、仅当EnableIpv6设置为true时，支持配置本参数。3、取值范围：0～255。掩码固定为/64。
        :param pulumi.Input[builtins.str] subnet_name: 子网的名称，长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不能以http://或https://开头，不填默认是子网的ID。
        """
        pulumi.set(__self__, "cidr_block", cidr_block)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "zone_id", zone_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_ipv6 is not None:
            pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        if ipv6_cidr_block is not None:
            pulumi.set(__self__, "ipv6_cidr_block", ipv6_cidr_block)
        if subnet_name is not None:
            pulumi.set(__self__, "subnet_name", subnet_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Input[builtins.str]:
        """
        子网的IPv4网段。
        """
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        子网所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[builtins.str]:
        """
        要创建的子网所属的可用区ID，更多可用区信息请参见地域和可用区。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不能以http://或https://开头。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        开启/关闭IPv6功能。仅当子网所属的VPC开通IPv6功能时，可配置此参数。1、true：开启。2、false：关闭。仅当子网内没有分配IPv6地址的云资源时，可配置此取值。
        """
        return pulumi.get(self, "enable_ipv6")

    @enable_ipv6.setter
    def enable_ipv6(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_ipv6", value)

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网IPv6网段。1、创建/修改时请输入子网IPv6网段的最后8比特位（子网的掩码固定为/64）。2、仅当EnableIpv6设置为true时，支持配置本参数。3、取值范围：0～255。掩码固定为/64。
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_cidr_block", value)

    @property
    @pulumi.getter(name="subnetName")
    def subnet_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网的名称，长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不能以http://或https://开头，不填默认是子网的ID。
        """
        return pulumi.get(self, "subnet_name")

    @subnet_name.setter
    def subnet_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SubnetTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SubnetTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _SubnetState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 available_ip_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_ipv6: Optional[pulumi.Input[builtins.bool]] = None,
                 ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 is_default: Optional[pulumi.Input[builtins.bool]] = None,
                 network_acl_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 read_ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 route_table: Optional[pulumi.Input['SubnetRouteTableArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['SubnetTagArgs']]]] = None,
                 total_ipv4_count: Optional[pulumi.Input[builtins.int]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Subnet resources.
        :param pulumi.Input[builtins.str] account_id: 子网所属账户的ID。
        :param pulumi.Input[builtins.int] available_ip_address_count: 子网中可用的IP地址数量。
        :param pulumi.Input[builtins.str] cidr_block: 子网的IPv4网段。
        :param pulumi.Input[builtins.str] created_time: 子网的创建时间。
        :param pulumi.Input[builtins.str] description: 子网的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不能以http://或https://开头。
        :param pulumi.Input[builtins.bool] enable_ipv6: 开启/关闭IPv6功能。仅当子网所属的VPC开通IPv6功能时，可配置此参数。1、true：开启。2、false：关闭。仅当子网内没有分配IPv6地址的云资源时，可配置此取值。
        :param pulumi.Input[builtins.str] ipv6_cidr_block: 子网IPv6网段。1、创建/修改时请输入子网IPv6网段的最后8比特位（子网的掩码固定为/64）。2、仅当EnableIpv6设置为true时，支持配置本参数。3、取值范围：0～255。掩码固定为/64。
        :param pulumi.Input[builtins.bool] is_default: 该子网是否为默认子网。1、true：默认子网，表示该子网是创建ECS实例时系统自动创建的子网。2、false：非默认子网，表示该子网是用户手动创建的。
        :param pulumi.Input[builtins.str] network_acl_id: 子网关联的网络ACL的ID。
        :param pulumi.Input[builtins.str] project_name: 子网所在VPC实例所属项目的名称。
        :param pulumi.Input[builtins.str] read_ipv6_cidr_block: 只读字段，子网IPv6网段。
        :param pulumi.Input['SubnetRouteTableArgs'] route_table: 路由表信息。
        :param pulumi.Input[builtins.str] status: 子网的状态。1、Pending：表示配置中。2、Available：表示可用。
        :param pulumi.Input[builtins.str] subnet_id: 待修改信息的子网的ID。
        :param pulumi.Input[builtins.str] subnet_name: 子网的名称，长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不能以http://或https://开头，不填默认是子网的ID。
        :param pulumi.Input[builtins.int] total_ipv4_count: 子网下可用IP总数。
        :param pulumi.Input[builtins.str] updated_time: 子网的更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 子网所属VPC的ID。
        :param pulumi.Input[builtins.str] zone_id: 要创建的子网所属的可用区ID，更多可用区信息请参见地域和可用区。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if available_ip_address_count is not None:
            pulumi.set(__self__, "available_ip_address_count", available_ip_address_count)
        if cidr_block is not None:
            pulumi.set(__self__, "cidr_block", cidr_block)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_ipv6 is not None:
            pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        if ipv6_cidr_block is not None:
            pulumi.set(__self__, "ipv6_cidr_block", ipv6_cidr_block)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if network_acl_id is not None:
            pulumi.set(__self__, "network_acl_id", network_acl_id)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if read_ipv6_cidr_block is not None:
            pulumi.set(__self__, "read_ipv6_cidr_block", read_ipv6_cidr_block)
        if route_table is not None:
            pulumi.set(__self__, "route_table", route_table)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if subnet_name is not None:
            pulumi.set(__self__, "subnet_name", subnet_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if total_ipv4_count is not None:
            pulumi.set(__self__, "total_ipv4_count", total_ipv4_count)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网所属账户的ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="availableIpAddressCount")
    def available_ip_address_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        子网中可用的IP地址数量。
        """
        return pulumi.get(self, "available_ip_address_count")

    @available_ip_address_count.setter
    def available_ip_address_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "available_ip_address_count", value)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网的IPv4网段。
        """
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不能以http://或https://开头。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        开启/关闭IPv6功能。仅当子网所属的VPC开通IPv6功能时，可配置此参数。1、true：开启。2、false：关闭。仅当子网内没有分配IPv6地址的云资源时，可配置此取值。
        """
        return pulumi.get(self, "enable_ipv6")

    @enable_ipv6.setter
    def enable_ipv6(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_ipv6", value)

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网IPv6网段。1、创建/修改时请输入子网IPv6网段的最后8比特位（子网的掩码固定为/64）。2、仅当EnableIpv6设置为true时，支持配置本参数。3、取值范围：0～255。掩码固定为/64。
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_cidr_block", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        该子网是否为默认子网。1、true：默认子网，表示该子网是创建ECS实例时系统自动创建的子网。2、false：非默认子网，表示该子网是用户手动创建的。
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter(name="networkAclId")
    def network_acl_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网关联的网络ACL的ID。
        """
        return pulumi.get(self, "network_acl_id")

    @network_acl_id.setter
    def network_acl_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_acl_id", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网所在VPC实例所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="readIpv6CidrBlock")
    def read_ipv6_cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        只读字段，子网IPv6网段。
        """
        return pulumi.get(self, "read_ipv6_cidr_block")

    @read_ipv6_cidr_block.setter
    def read_ipv6_cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "read_ipv6_cidr_block", value)

    @property
    @pulumi.getter(name="routeTable")
    def route_table(self) -> Optional[pulumi.Input['SubnetRouteTableArgs']]:
        """
        路由表信息。
        """
        return pulumi.get(self, "route_table")

    @route_table.setter
    def route_table(self, value: Optional[pulumi.Input['SubnetRouteTableArgs']]):
        pulumi.set(self, "route_table", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网的状态。1、Pending：表示配置中。2、Available：表示可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        待修改信息的子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="subnetName")
    def subnet_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网的名称，长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不能以http://或https://开头，不填默认是子网的ID。
        """
        return pulumi.get(self, "subnet_name")

    @subnet_name.setter
    def subnet_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SubnetTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SubnetTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="totalIpv4Count")
    def total_ipv4_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        子网下可用IP总数。
        """
        return pulumi.get(self, "total_ipv4_count")

    @total_ipv4_count.setter
    def total_ipv4_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "total_ipv4_count", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        要创建的子网所属的可用区ID，更多可用区信息请参见地域和可用区。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:vpc/subnet:Subnet")
class Subnet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_ipv6: Optional[pulumi.Input[builtins.bool]] = None,
                 ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SubnetTagArgs', 'SubnetTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        子网是在指定可用区内分配的一段VPC网段内的网段，它为云上资源（如云服务器、负载均衡等）提供私网IP地址。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        subnet_demo = bytepluscc.vpc.Subnet("SubnetDemo",
            vpc_id="vpc-xxxx",
            zone_id="cn-beijing",
            subnet_name="subnetDemo",
            description="subnetDemo description",
            cidr_block="192.168.xx.0/24",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/subnet:Subnet example "subnet_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cidr_block: 子网的IPv4网段。
        :param pulumi.Input[builtins.str] description: 子网的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不能以http://或https://开头。
        :param pulumi.Input[builtins.bool] enable_ipv6: 开启/关闭IPv6功能。仅当子网所属的VPC开通IPv6功能时，可配置此参数。1、true：开启。2、false：关闭。仅当子网内没有分配IPv6地址的云资源时，可配置此取值。
        :param pulumi.Input[builtins.str] ipv6_cidr_block: 子网IPv6网段。1、创建/修改时请输入子网IPv6网段的最后8比特位（子网的掩码固定为/64）。2、仅当EnableIpv6设置为true时，支持配置本参数。3、取值范围：0～255。掩码固定为/64。
        :param pulumi.Input[builtins.str] subnet_name: 子网的名称，长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不能以http://或https://开头，不填默认是子网的ID。
        :param pulumi.Input[builtins.str] vpc_id: 子网所属VPC的ID。
        :param pulumi.Input[builtins.str] zone_id: 要创建的子网所属的可用区ID，更多可用区信息请参见地域和可用区。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SubnetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        子网是在指定可用区内分配的一段VPC网段内的网段，它为云上资源（如云服务器、负载均衡等）提供私网IP地址。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        subnet_demo = bytepluscc.vpc.Subnet("SubnetDemo",
            vpc_id="vpc-xxxx",
            zone_id="cn-beijing",
            subnet_name="subnetDemo",
            description="subnetDemo description",
            cidr_block="192.168.xx.0/24",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/subnet:Subnet example "subnet_id"
        ```

        :param str resource_name: The name of the resource.
        :param SubnetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SubnetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_ipv6: Optional[pulumi.Input[builtins.bool]] = None,
                 ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SubnetTagArgs', 'SubnetTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SubnetArgs.__new__(SubnetArgs)

            if cidr_block is None and not opts.urn:
                raise TypeError("Missing required property 'cidr_block'")
            __props__.__dict__["cidr_block"] = cidr_block
            __props__.__dict__["description"] = description
            __props__.__dict__["enable_ipv6"] = enable_ipv6
            __props__.__dict__["ipv6_cidr_block"] = ipv6_cidr_block
            __props__.__dict__["subnet_name"] = subnet_name
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id'")
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["account_id"] = None
            __props__.__dict__["available_ip_address_count"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["is_default"] = None
            __props__.__dict__["network_acl_id"] = None
            __props__.__dict__["project_name"] = None
            __props__.__dict__["read_ipv6_cidr_block"] = None
            __props__.__dict__["route_table"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["subnet_id"] = None
            __props__.__dict__["total_ipv4_count"] = None
            __props__.__dict__["updated_time"] = None
        super(Subnet, __self__).__init__(
            'bytepluscc:vpc/subnet:Subnet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            available_ip_address_count: Optional[pulumi.Input[builtins.int]] = None,
            cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enable_ipv6: Optional[pulumi.Input[builtins.bool]] = None,
            ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            is_default: Optional[pulumi.Input[builtins.bool]] = None,
            network_acl_id: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            read_ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            route_table: Optional[pulumi.Input[Union['SubnetRouteTableArgs', 'SubnetRouteTableArgsDict']]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            subnet_name: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SubnetTagArgs', 'SubnetTagArgsDict']]]]] = None,
            total_ipv4_count: Optional[pulumi.Input[builtins.int]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Subnet':
        """
        Get an existing Subnet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 子网所属账户的ID。
        :param pulumi.Input[builtins.int] available_ip_address_count: 子网中可用的IP地址数量。
        :param pulumi.Input[builtins.str] cidr_block: 子网的IPv4网段。
        :param pulumi.Input[builtins.str] created_time: 子网的创建时间。
        :param pulumi.Input[builtins.str] description: 子网的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不能以http://或https://开头。
        :param pulumi.Input[builtins.bool] enable_ipv6: 开启/关闭IPv6功能。仅当子网所属的VPC开通IPv6功能时，可配置此参数。1、true：开启。2、false：关闭。仅当子网内没有分配IPv6地址的云资源时，可配置此取值。
        :param pulumi.Input[builtins.str] ipv6_cidr_block: 子网IPv6网段。1、创建/修改时请输入子网IPv6网段的最后8比特位（子网的掩码固定为/64）。2、仅当EnableIpv6设置为true时，支持配置本参数。3、取值范围：0～255。掩码固定为/64。
        :param pulumi.Input[builtins.bool] is_default: 该子网是否为默认子网。1、true：默认子网，表示该子网是创建ECS实例时系统自动创建的子网。2、false：非默认子网，表示该子网是用户手动创建的。
        :param pulumi.Input[builtins.str] network_acl_id: 子网关联的网络ACL的ID。
        :param pulumi.Input[builtins.str] project_name: 子网所在VPC实例所属项目的名称。
        :param pulumi.Input[builtins.str] read_ipv6_cidr_block: 只读字段，子网IPv6网段。
        :param pulumi.Input[Union['SubnetRouteTableArgs', 'SubnetRouteTableArgsDict']] route_table: 路由表信息。
        :param pulumi.Input[builtins.str] status: 子网的状态。1、Pending：表示配置中。2、Available：表示可用。
        :param pulumi.Input[builtins.str] subnet_id: 待修改信息的子网的ID。
        :param pulumi.Input[builtins.str] subnet_name: 子网的名称，长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不能以http://或https://开头，不填默认是子网的ID。
        :param pulumi.Input[builtins.int] total_ipv4_count: 子网下可用IP总数。
        :param pulumi.Input[builtins.str] updated_time: 子网的更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 子网所属VPC的ID。
        :param pulumi.Input[builtins.str] zone_id: 要创建的子网所属的可用区ID，更多可用区信息请参见地域和可用区。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SubnetState.__new__(_SubnetState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["available_ip_address_count"] = available_ip_address_count
        __props__.__dict__["cidr_block"] = cidr_block
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_ipv6"] = enable_ipv6
        __props__.__dict__["ipv6_cidr_block"] = ipv6_cidr_block
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["network_acl_id"] = network_acl_id
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["read_ipv6_cidr_block"] = read_ipv6_cidr_block
        __props__.__dict__["route_table"] = route_table
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["subnet_name"] = subnet_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["total_ipv4_count"] = total_ipv4_count
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_id"] = zone_id
        return Subnet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        子网所属账户的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="availableIpAddressCount")
    def available_ip_address_count(self) -> pulumi.Output[builtins.int]:
        """
        子网中可用的IP地址数量。
        """
        return pulumi.get(self, "available_ip_address_count")

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        子网的IPv4网段。
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        子网的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        子网的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不能以http://或https://开头。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> pulumi.Output[builtins.bool]:
        """
        开启/关闭IPv6功能。仅当子网所属的VPC开通IPv6功能时，可配置此参数。1、true：开启。2、false：关闭。仅当子网内没有分配IPv6地址的云资源时，可配置此取值。
        """
        return pulumi.get(self, "enable_ipv6")

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        子网IPv6网段。1、创建/修改时请输入子网IPv6网段的最后8比特位（子网的掩码固定为/64）。2、仅当EnableIpv6设置为true时，支持配置本参数。3、取值范围：0～255。掩码固定为/64。
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[builtins.bool]:
        """
        该子网是否为默认子网。1、true：默认子网，表示该子网是创建ECS实例时系统自动创建的子网。2、false：非默认子网，表示该子网是用户手动创建的。
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="networkAclId")
    def network_acl_id(self) -> pulumi.Output[builtins.str]:
        """
        子网关联的网络ACL的ID。
        """
        return pulumi.get(self, "network_acl_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        子网所在VPC实例所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="readIpv6CidrBlock")
    def read_ipv6_cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        只读字段，子网IPv6网段。
        """
        return pulumi.get(self, "read_ipv6_cidr_block")

    @property
    @pulumi.getter(name="routeTable")
    def route_table(self) -> pulumi.Output['outputs.SubnetRouteTable']:
        """
        路由表信息。
        """
        return pulumi.get(self, "route_table")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        子网的状态。1、Pending：表示配置中。2、Available：表示可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        待修改信息的子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="subnetName")
    def subnet_name(self) -> pulumi.Output[builtins.str]:
        """
        子网的名称，长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不能以http://或https://开头，不填默认是子网的ID。
        """
        return pulumi.get(self, "subnet_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.SubnetTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="totalIpv4Count")
    def total_ipv4_count(self) -> pulumi.Output[builtins.int]:
        """
        子网下可用IP总数。
        """
        return pulumi.get(self, "total_ipv4_count")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        子网的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        子网所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        要创建的子网所属的可用区ID，更多可用区信息请参见地域和可用区。
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'EndpointServicePrivateDnsNameConfiguration',
    'EndpointServiceResource',
    'EndpointServiceTag',
    'GetEndpointServicePrivateDnsNameConfigurationResult',
    'GetEndpointServiceResourceResult',
    'GetEndpointServiceTagResult',
]

@pulumi.output_type
class EndpointServicePrivateDnsNameConfiguration(dict):
    def __init__(__self__, *,
                 name: Optional[builtins.str] = None,
                 status: Optional[builtins.str] = None,
                 type: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str name: 域验证名称。
        :param builtins.str status: 域验证状态。PendingVerification：待验证Verifying：验证中Verified：验证通过Failed：验证失败
        :param builtins.str type: 域验证类型。TXT：TXT记录。
        :param builtins.str value: 域验证值。
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        域验证名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        域验证状态。PendingVerification：待验证Verifying：验证中Verified：验证通过Failed：验证失败
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        域验证类型。TXT：TXT记录。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        域验证值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class EndpointServiceResource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "instanceId":
            suggest = "instance_id"
        elif key == "resourceId":
            suggest = "resource_id"
        elif key == "zoneIds":
            suggest = "zone_ids"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in EndpointServiceResource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        EndpointServiceResource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        EndpointServiceResource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 instance_id: Optional[builtins.str] = None,
                 resource_id: Optional[builtins.str] = None,
                 zone_ids: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.str instance_id: 终端节点服务ID。
        :param builtins.str resource_id: 待添加到终端节点服务中的服务资源ID。
        :param Sequence[builtins.str] zone_ids: 负载均衡提供服务的可用区。
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if zone_ids is not None:
            pulumi.set(__self__, "zone_ids", zone_ids)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[builtins.str]:
        """
        终端节点服务ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[builtins.str]:
        """
        待添加到终端节点服务中的服务资源ID。
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> Optional[Sequence[builtins.str]]:
        """
        负载均衡提供服务的可用区。
        """
        return pulumi.get(self, "zone_ids")


@pulumi.output_type
class EndpointServiceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 终端节点服务标签的标签键。
        :param builtins.str value: 终端节点服务标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        终端节点服务标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        终端节点服务标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetEndpointServicePrivateDnsNameConfigurationResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 status: builtins.str,
                 type: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str name: 域验证名称。
        :param builtins.str status: 域验证状态。PendingVerification：待验证Verifying：验证中Verified：验证通过Failed：验证失败
        :param builtins.str type: 域验证类型。TXT：TXT记录。
        :param builtins.str value: 域验证值。
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        域验证名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        域验证状态。PendingVerification：待验证Verifying：验证中Verified：验证通过Failed：验证失败
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        域验证类型。TXT：TXT记录。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        域验证值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetEndpointServiceResourceResult(dict):
    def __init__(__self__, *,
                 instance_id: builtins.str,
                 resource_id: builtins.str,
                 zone_ids: Sequence[builtins.str]):
        """
        :param builtins.str instance_id: 终端节点服务ID。
        :param builtins.str resource_id: 待添加到终端节点服务中的服务资源ID。
        :param Sequence[builtins.str] zone_ids: 负载均衡提供服务的可用区。
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "resource_id", resource_id)
        pulumi.set(__self__, "zone_ids", zone_ids)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        终端节点服务ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> builtins.str:
        """
        待添加到终端节点服务中的服务资源ID。
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="zoneIds")
    def zone_ids(self) -> Sequence[builtins.str]:
        """
        负载均衡提供服务的可用区。
        """
        return pulumi.get(self, "zone_ids")


@pulumi.output_type
class GetEndpointServiceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 终端节点服务标签的标签键。
        :param builtins.str value: 终端节点服务标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        终端节点服务标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        终端节点服务标签的标签值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'NgwEipAddressArgs',
    'NgwEipAddressArgsDict',
    'NgwNatIpAddressArgs',
    'NgwNatIpAddressArgsDict',
    'NgwTagArgs',
    'NgwTagArgsDict',
]

MYPY = False

if not MYPY:
    class NgwEipAddressArgsDict(TypedDict):
        allocation_id: NotRequired[pulumi.Input[builtins.str]]
        """
        公网IP的ID。
        """
        eip_address: NotRequired[pulumi.Input[builtins.str]]
        """
        公网IP的地址。
        """
        using_status: NotRequired[pulumi.Input[builtins.str]]
        """
        公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
elif False:
    NgwEipAddressArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NgwEipAddressArgs:
    def __init__(__self__, *,
                 allocation_id: Optional[pulumi.Input[builtins.str]] = None,
                 eip_address: Optional[pulumi.Input[builtins.str]] = None,
                 using_status: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] allocation_id: 公网IP的ID。
        :param pulumi.Input[builtins.str] eip_address: 公网IP的地址。
        :param pulumi.Input[builtins.str] using_status: 公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        if allocation_id is not None:
            pulumi.set(__self__, "allocation_id", allocation_id)
        if eip_address is not None:
            pulumi.set(__self__, "eip_address", eip_address)
        if using_status is not None:
            pulumi.set(__self__, "using_status", using_status)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        公网IP的ID。
        """
        return pulumi.get(self, "allocation_id")

    @allocation_id.setter
    def allocation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allocation_id", value)

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        公网IP的地址。
        """
        return pulumi.get(self, "eip_address")

    @eip_address.setter
    def eip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_address", value)

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        公网IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")

    @using_status.setter
    def using_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "using_status", value)


if not MYPY:
    class NgwNatIpAddressArgsDict(TypedDict):
        nat_ip_address: NotRequired[pulumi.Input[builtins.str]]
        """
        中转Ip地址。
        """
        nat_ip_id: NotRequired[pulumi.Input[builtins.str]]
        """
        中转Ip id。
        """
elif False:
    NgwNatIpAddressArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NgwNatIpAddressArgs:
    def __init__(__self__, *,
                 nat_ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] nat_ip_address: 中转Ip地址。
        :param pulumi.Input[builtins.str] nat_ip_id: 中转Ip id。
        """
        if nat_ip_address is not None:
            pulumi.set(__self__, "nat_ip_address", nat_ip_address)
        if nat_ip_id is not None:
            pulumi.set(__self__, "nat_ip_id", nat_ip_id)

    @property
    @pulumi.getter(name="natIpAddress")
    def nat_ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转Ip地址。
        """
        return pulumi.get(self, "nat_ip_address")

    @nat_ip_address.setter
    def nat_ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_address", value)

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转Ip id。
        """
        return pulumi.get(self, "nat_ip_id")

    @nat_ip_id.setter
    def nat_ip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_id", value)


if not MYPY:
    class NgwTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签值。
        """
elif False:
    NgwTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NgwTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 用户标签的标签键。
        :param pulumi.Input[builtins.str] value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


